# cfcli

[![PyPI Version](https://img.shields.io/pypi/v/cfcli.svg)](https://pypi.org/project/cfcli/)
[![Upload Python Package](https://github.com/IotaSpencer/cfclipy/actions/workflows/python-publish.yml/badge.svg)](https://github.com/IotaSpencer/cfclipy/actions/workflows/python-publish.yml)

A command line tool for interacting with Cloudflare's API.


## Installation

(This should be able to be ran with pipx as long as you have a config file set up.)

#### Otherwise

`pip install clickflare`